@@ -1,6 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from sql import Null
+from sql.conditionals import Case
 
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pyson import If, Eval, Bool
@@ -50,7 +51,7 @@ class ProductLocation(ModelSQL, ModelView):
     @staticmethod
     def order_sequence(tables):
         table, _ = tables[None]
-        return [table.sequence == Null, table.sequence]
+        return [Case((table.sequence == Null, 0), else_=1), table.sequence]
 
 
 class ShipmentIn:
